<?php

/**
	 * "Conditional get X% off all items in one or more categories" Discount Module
	 * Module created by johnnybegood 
	 * Last Revised: 22/11/2009
	 * Associated forum link: http://www.interspire.com/forum/showthread.php?t=14923
*/

class RULE_PERCENTOFFITEMSINCAT extends ISC_RULE
{
	private $amount;
	private $catids;
	private $clause;
	private $triggerproductqty;
	private $triggerproduct;
	private $triggerproductid;
	private $minimumorder;
	private $storewide;
	private $forcediscountmessage;
	private $calculateonbulkdiscounts;
	private $cartqty;
	private $cartqtylimit;
	protected $vendorSupport = true;

	public function __Construct($amount=0, $catids=array())
	{
		parent::__construct();

		$this->amount = $amount;
		$this->catids = $catids;

		$this->setName('PERCENTOFFITEMSINCAT');
		$this->displayName = GetLang($this->getName().'displayName');

		$this->addJavascriptValidation('amount', 'int', 0, 100);
		$this->addJavascriptValidation('catids', 'array');

		$this->addActionType('itemdiscount');
		$this->ruleType = 'Product';
	}

	public function initialize($data)
	{
		parent::initialize($data);

		$tmp = unserialize($data['configdata']);

		$this->amount = $tmp['var_amount'];
		$this->catids = $tmp['var_catids'];
		
		// 0=apply rule at all times | 1=apply rule when item x in cart | 2=apply rule when cart total >$x | 3=apply rule when items in cart > x
		$this->clause = $tmp['var_clause'];
		
		$this->triggerproductqty = $tmp['var_triggerproductqty'];
		$this->triggerproduct = $tmp['var_triggerproduct'];
		$this->triggerproductid = $tmp['var_triggerproductid'];
		
		$this->minimumorder = $tmp['var_minimumorder'];
		
		if (isset($tmp['var_storewide'])) {
			$this->storewide = 1;
		} else {
			$this->storewide = 0;
		}
		
		if ($tmp['var_forcediscountmessage'] == "on") {
			$this->forcediscountmessage = 1;
		} else {
			$this->forcediscountmessage = 0;
		}
		
		if ($tmp['var_calculateonbulkdiscounts'] == "on") {
			$this->calculateonbulkdiscounts = 1;
		} else {
			$this->calculateonbulkdiscounts = 0;
		}
		
		$this->cartqty = $tmp['var_cartqty'];
		
		if (isset($tmp['var_cartqtylimit'])) {
			$this->cartqtylimit = 1;
		} else {
			$this->cartqtylimit = 0;
		}
		
		
	}

	public function initializeAdmin()
	{
		if (!empty($this->catids)) {
			$selectedCategories = explode(',', $this->catids);
		} else {
			$selectedCategories = array();
		}

		$GLOBALS['ISC_CLASS_ADMIN_CATEGORY'] = GetClass('ISC_ADMIN_CATEGORY');
		$GLOBALS['CategoryList'] = $GLOBALS["ISC_CLASS_ADMIN_CATEGORY"]->GetCategoryOptions($selectedCategories, "<option %s value='%d'>%s</option>", 'selected="selected"', " ", false);

		if (count($selectedCategories) < 1) {
			$GLOBALS['AllCategoriesSelected'] = "selected=\"selected\"";
		}
		
		$currency = GetDefaultCurrency();
		if ($currency['currencystringposition'] == "LEFT") {
			$GLOBALS['CurrencyLeft'] = $currency['currencystring'];
		}
		else {
			$GLOBALS['CurrencyRight'] =  $currency['currencystring'];
		}		
		
		if ($this->clause == "1") {
			$GLOBALS['Clause1'] = 'checked="checked"';
		} elseif ($this->clause == "2") {
			$GLOBALS['Clause2'] = 'checked="checked"';
		} elseif ($this->clause == "3") {
			$GLOBALS['Clause3'] = 'checked="checked"';
		} else {
			$GLOBALS['Clause0'] = 'checked="checked"';
		}
		
		
		// If we're using a cart quantity drop down, load that
		if (GetConfig('TagCartQuantityBoxes') == 'dropdown') {
			$GLOBALS['SelectId'] = "triggerproductqty";
			$GLOBALS['Qty0'] = Interspire_Template::getInstance('admin')->render('Snippets/DiscountItemQtySelect.html');
		// Otherwise, load the textbox
		} else {
			$GLOBALS['SelectId'] = "triggerproductqty";
			$GLOBALS['Qty0'] = Interspire_Template::getInstance('admin')->render('Snippets/DiscountItemQtyText.html');
		}
		
		// If we're using a cart quantity drop down, load that
		if (GetConfig('TagCartQuantityBoxes') == 'dropdown') {
			$GLOBALS['SelectId'] = "cartqty";
			$GLOBALS['Qty1'] = Interspire_Template::getInstance('admin')->render('Snippets/DiscountItemQtySelect.html');
		// Otherwise, load the textbox
		} else {
			$GLOBALS['SelectId'] = "cartqty";
			$GLOBALS['Qty1'] = Interspire_Template::getInstance('admin')->render('Snippets/DiscountItemQtyText.html');
		}
		
		
		if (!isset($GLOBALS['var_triggerproduct'])) {
			$GLOBALS['var_triggerproduct'] = GetLang('ChooseAProduct');
		}
		
		if ($this->storewide == 1)  {
			$GLOBALS['StoreWide'] = 'checked="checked"';
		} else {
			$GLOBALS['StoreWide'] = '';
		} 		
	
		if ($this->forcediscountmessage == 1)  {
			$GLOBALS['ForceDiscountMessage'] = 'checked="checked"';
		} elseif (!isset($this->forcediscountmessage)) {
			$GLOBALS['ForceDiscountMessage'] = 'checked="checked"';
		} else {
			$GLOBALS['ForceDiscountMessage'] = '';
		} 
		
		if ($this->calculateonbulkdiscounts == 1)  {
			$GLOBALS['CalculateOnBulkDiscounts'] = 'checked="checked"';
		} elseif (!isset($this->calculateonbulkdiscounts)) {
			$GLOBALS['CalculateOnBulkDiscounts'] = 'checked="checked"';
		} else {
			$GLOBALS['CalculateOnBulkDiscounts'] = '';
		} 
		
		if ($this->cartqtylimit == 1)  {
			$GLOBALS['CartQtyLimit'] = 'checked="checked"';
		} else {
			$GLOBALS['CartQtyLimit'] = '';
		} 
	}
	
	
	public function resetState(ISC_QUOTE $quote)
	{
		$quote->addDiscount($this->getDbId(), 0);

		// Remove the discount amounts for this rule from all products
		foreach($quote->getItems() as $item) {
			$item->addDiscount($this->getDbId(), 0);
		}
	}
	
	
	public function isTrue()
	{
		$currency = GetDefaultCurrency();
		if ($currency['currencystringposition'] == "LEFT") {
			$GLOBALS['CurrencyLeft'] = $currency['currencystring'];
			$GLOBALS['CurrencyRight'] =  '';
		}
		else {
			$GLOBALS['CurrencyRight'] =  $currency['currencystring'];
			$GLOBALS['CurrencyLeft'] = '';
		}		
		
		//$GLOBALS['ISC_CLASS_CART'] = GetClass('ISC_CART');

		//$cartProducts = $GLOBALS['ISC_CLASS_CART']->api->GetProductsInCart(true);
		
		$found = false;
		$items = $quote->getItems();
		$ruleCats = explode(',', $this->catids);
		
		//$cartTotal = $GLOBALS['ISC_CLASS_CART']->api->GetCartSubTotal(false, null, true, true);
		$cartTotal = $quote->getSubTotal();
		
		//$found = false;
		
		$productincart = 0;
		$discountcatitems = 0;
		$triggerproductactive = 0;
		$setquantity = 0;
		
		
		// The discount needs to come off each item, so that tax is also affected.
		$totalDiscount = 0;
		foreach($items as $item) {
			$apply = false;
			if($item instanceof ISC_QUOTE_ITEM_GIFTCERTIFICATE) {
				continue;
			}
	
			//NOTE: Replace $product with $item
			/*
			 * Make calls to QUOTE::item object
			 */
			
		//foreach ($cartProducts as $key=>$product) {
			//if ($product['product_id'] == $this->triggerproductid) {
			if($item->getProductId() == $this->triggerproductid) {
				$productincart = 1;
				//$setquantity = $product['quantity'];
				$setquantity = $item->getQuantity();
					
				//determine if trigger product has sufficient quantity
				//if ($productincart ==  1 && $product['quantity'] >= $this->triggerproductqty) {
				if ($productincart ==  1 && $setquantity >= $this->triggerproductqty) {
					$triggerproductactive = 1;	
				}
			}
			
			//$productCats = explode(",", $product['data']['categoryids']);
			$categoryIds = $item->getCategoryIds();
			$ruleCats = explode(",", $this->catids);
			
			//foreach ($ruleCats as $catid) {
			foreach ($ruleCats as $categoryId) {
				
				if(!in_array($categoryId, $categoryIds) && $categoryId != 0) {
					continue;
				}
			
				//determine if an item from any of the selected discount categories is present in the cart
				//if (in_array($catid, $categoryIds)) {
				if (in_array($categoryId, $categoryIds)) {
					$discountcatitems = 1;
					//$discountitemqty[] = $product['quantity'];
					$discountitemqty[] = $setquantity;
				}	

				//$found[] = $catid;
				$found[] = $categoryId;
			}
		}

		if (isset($discountitemqty)) {
			$discountitemqty = array_sum($discountitemqty);
		} else {
			$discountitemqty = 0;
		}
		
		//$num_items = $_SESSION['CART']['NUM_ITEMS'];
		$num_items = $quote->getNumItems();
	
		//foreach ($cartProducts as $key=>$product) {
		foreach($items as $item) {
			$apply = false;
			
			//if a coupon is active this discount module will be deactivated
			//$coupons = $GLOBALS['ISC_CLASS_CART']->api->GetAppliedCouponCodes();
			$coupons = $quote->getAppliedCoupons();
			
			if (count($coupons)) {
				if ($this->forcediscountmessage == 1) {
					$this->clause = 9;
				} else {
					$this->clause = 8; //won't display any message
				}
				
				//lets get out of here!
				continue;
			} 
			
//			if ((isset($product['type']) && $product['type'] == 'giftcertificate') || ($this->clause == 1 && $triggerproductactive == 0) || ($this->clause == 2 && $cartTotal < $this->minimumorder) || ($this->clause == 3 && $num_items < $this->cartqty && $this->cartqtylimit == 0) || ($this->clause == 3 && $discountitemqty < $this->cartqty && $this->cartqtylimit == 1)) {
//				continue;
//			}
			
			if($item instanceof ISC_QUOTE_ITEM_GIFTCERTIFICATE || ($this->clause == 1 && $triggerproductactive == 0) || ($this->clause == 2 && $cartTotal < $this->minimumorder) || ($this->clause == 3 && $num_items < $this->cartqty && $this->cartqtylimit == 0) || ($this->clause == 3 && $discountitemqty < $this->cartqty && $this->cartqtylimit == 1)) {
				continue;
			}

			
			/*
			 * Affects whole store
			 */
			if ($this->storewide== 1) {
/*
				if ($this->calculateonbulkdiscounts == 1) {
					$price = $product['original_price'];
						
					if (isset($product['discount_price'])) {
						$amount = $product['original_price'] * ((int)$this->amount/100);
					} else {
						$amount = $product['original_price'] * ((int)$this->amount/100);
					}
					
				} else {
					$price = $item->getBaseTotal();
					
					$price = $product['product_price'];
					
					if (isset($product['discount_price'])) {
						$amount = $product['discount_price'] * ((int)$this->amount/100);
					} else {
						$amount = $product['product_price'] * ((int)$this->amount/100);
					}
				}

				if ($amount < 0) {
					$amount = 0;
				}
					
				$this->itemdiscount += $amount * $product['quantity'];
				$GLOBALS['ISC_CLASS_CART']->api->SetItemValue($key, 'discount_price', $price - $amount);
 */
				
				$price = $item->getBaseTotal();
				
				$discountAmount = $price * ($this->amount / 100);
				$discountAmount = round($discountAmount, getConfig('DecimalPlaces'));
				if($item->getBaseTotal() - $discountAmount < 0) {
					$discountAmount = 0;
				}

				$item->addDiscount($this->getDbId(), $discountAmount);
				$totalDiscount += $discountAmount;
			}
			else {

				//$productCats = explode(",", $product['data']['categoryids']);
				$categoryIds = $item->getCategoryIds();
				$ruleCats = explode(",", $this->catids);
				foreach ($ruleCats as $catid) {
					//if (in_array($catid, $productCats) || $catid == 0) {
					if (!in_array($catid, $categoryIds) || $catid == 0) {
						continue;
					}
					$apply = true;
					$found[] = $categoryId;
				}

				if(!$apply) {
					continue;
				}
/*
					if ($this->calculateonbulkdiscounts == 1) {
						//$price = $product['original_price'];
						$price = $item->getBaseTotal();
					  
					 
					 	if (isset($product['discount_price'])) {
							$amount = $product['original_price'] * ((int)$this->amount/100);
						} else {
							$amount = $product['original_price'] * ((int)$this->amount/100);
						}
 
						$amount = $price * ((int)$this->amount/100);
					
					} else {					
						//$price = $product['product_price'];
						$discount = $item->getDiscounts();

						if (isset($product['discount_price'])) {
							$amount = $product['discount_price'] * ((int)$this->amount/100);
						} else {
							$amount = $product['product_price'] * ((int)$this->amount/100);
						}

						if (!empty($discount)) {
							$amount = $discount * ((int)$this->amount/100);
						} else {
							$amount = $product['product_price'] * ((int)$this->amount/100);
						}
					}

					if ($amount < 0) {
						$amount = 0;
					}
									
					$this->itemdiscount += $amount * $product['quantity'];
					$GLOBALS['ISC_CLASS_CART']->api->SetItemValue($key, 'discount_price', $price - $amount);		
		
				//run the discount passed all products if the "storewide" option is checked
				} elseif ($this->storewide== 1) {
					
					if ($this->calculateonbulkdiscounts == 1) {
						$price = $product['original_price'];
						
						if (isset($product['discount_price'])) {
							$amount = $product['original_price'] * ((int)$this->amount/100);
						} else {
							$amount = $product['original_price'] * ((int)$this->amount/100);
						}
					
					} else {					
						$price = $product['product_price'];
						
						if (isset($product['discount_price'])) {
							$amount = $product['discount_price'] * ((int)$this->amount/100);
						} else {
							$amount = $product['product_price'] * ((int)$this->amount/100);
						}
					
					}

					if ($amount < 0) {
						$amount = 0;
					}
					
					$this->itemdiscount += $amount * $product['quantity'];
					$GLOBALS['ISC_CLASS_CART']->api->SetItemValue($key, 'discount_price', $price - $amount);
  
				}
*/				
				$price = $item->getBaseTotal();
				
				$discountAmount = $price * ($this->amount / 100);
				$discountAmount = round($discountAmount, getConfig('DecimalPlaces'));
				if($item->getBaseTotal() - $discountAmount < 0) {
					$discountAmount = 0;
				}

				$item->addDiscount($this->getDbId(), $discountAmount);
				$totalDiscount += $discountAmount;
			}
	
		}
		
		/*
		 * No discounts to apply so fail gracefully
		 */
		if(empty($found) || ($this->storewide ==1 && empty($totalDiscount))) {
			return false;
		}
		
		if(count($found) >= 1) {
			//Generate category names and links
			$catname = '';
			$catids = implode(',', $found);

			$query = "
					SELECT catname, categoryid
					FROM [|PREFIX|]categories
					WHERE categoryid IN ($catids)
			";

			$result = $GLOBALS['ISC_CLASS_DB']->Query($query);

			while($var = $GLOBALS['ISC_CLASS_DB']->Fetch($result)) {
				$catname[] = $var['catname'];
				$catlink1[] = '<a href="'.CatLink($var['categoryid'], $var['catname']).'">'.$var['catname'].'</a>';
			}		
		
			//use "categories" instead of "category" when >1 category is selected for discounting
			if (isset($catname{1})) {
				$categorytext = " categories";	
				$categorytext2 = " these categories";	
			} else {
				$categorytext = " category";
				$categorytext2 = " this category";
			}
		}
		
		//Get formated minimum order values
		$minimumordertext = $GLOBALS['CurrencyLeft'].(number_format($this->minimumorder, 2)).$GLOBALS['CurrencyRight'];
		$spendtoqualifytext = $GLOBALS['CurrencyLeft'].(number_format(($this->minimumorder - $cartTotal), 2)).$GLOBALS['CurrencyRight'];

		//Generate text for messages...
		if ($this->storewide == 1) {
			$catlink = "everything!";
		} else {
			$catlink = "all items from the ".implode(" and ",$catlink1).$categorytext;
		}
		
		//Probably not the cleanest way to do this
		if ($this->cartqtylimit == 1 && $this->storewide == 1) {
			$mess1 = "from the ".implode(" and ",$catlink1).$categorytext;
			$mess2 = "everything storewide!";
		} elseif ($this->cartqtylimit == 1 && $this->storewide == 0)  {
			$mess1 = "from the ".implode(" and ",$catlink1).$categorytext;
			$mess2 = "all items from ".$categorytext2;
			if ($discountitemqty >= $this->cartqty) {
				$mess2 = "all items from the ".implode(" and ",$catlink1).$categorytext;
			}
		} elseif ($this->cartqtylimit == 0 && $this->storewide == 1)  {
			$mess1 = "from any category";
			$mess2 = "everything storewide!";
		} elseif ($this->cartqtylimit == 0 && $this->storewide == 0)  {
			$mess1 = "from any category";
			$mess2 = "all items from the ".implode(" and ",$catlink1).$categorytext;
		}
		
		if ($this->cartqtylimit == 1) {
			$currentcartqty = $discountitemqty;
		} else {
			$currentcartqty = $num_items;	
		}
		
		$itemstilltrigger = ($this->cartqty - $currentcartqty);
		if ($itemstilltrigger == $this->cartqty) {
			$itemstilltrigger = $this->cartqty;
		} else {
			$itemstilltrigger = "another ".$itemstilltrigger;	
		}
		
		$triggeritemlink = ProdLink($this->triggerproduct);
		$triggeritemaddlink = CartLink($this->triggerproductid).'&qty['.($this->triggerproductqty - $setquantity).']='.($this->triggerproductqty - $setquantity);
		
		//Set message for when discount excludes product level discounts
		if ($this->calculateonbulkdiscounts == 1) {
			$discountexcludes = sprintf(GetLang($this->getName().'DiscountExcludes'));
		} else {
			$discountexcludes = sprintf(GetLang($this->getName().'DiscountIncludes'));
		}

		//Run messages when no clause is set
		
		//Message 1 - Clause = 0 [+] discount category item in cart = NO [+] forced discount message = YES
		if ($this->clause == 0 && $discountcatitems == 0 && $this->storewide == 0 && $this->forcediscountmessage == 1) {	
			$GLOBALS['ISC_CLASS_CART']->api->SetArrayPush('DISCOUNT_MESSAGES2', sprintf(GetLang($this->getName().'DiscountMessage1'), $this->amount, $catlink, $discountexcludes));
			
		//Message 2 - Clause = 0 [+] discount category item in cart = YES
		} elseif ($this->clause == 0 && ($this->storewide == 1 || $discountcatitems == 1)) {
			$GLOBALS['ISC_CLASS_CART']->api->SetArrayPush('DISCOUNT_MESSAGES', sprintf(GetLang($this->getName().'DiscountMessage2'), $this->amount, $catlink, $discountexcludes));		
			
		
		//Run messages for the product in cart clause
		
		//Message 3 - Clause = 1 [+] trigger item in cart = NO [+] discount category item in cart = NO [+] forced discount message = YES
		} elseif ($this->clause == 1 && $productincart == 0 && $discountcatitems == 0 && $this->forcediscountmessage == 1) {	
			$GLOBALS['ISC_CLASS_CART']->api->SetArrayPush('DISCOUNT_MESSAGES2', sprintf(GetLang($this->getName().'DiscountMessage3'), $this->triggerproductqty, $triggeritemlink, $this->triggerproduct, $this->amount, $catlink, $triggeritemaddlink, ($this->triggerproductqty - $setquantity), $this->triggerproduct, $discountexcludes));
			
		//Message 4 - Clause = 1 [+] trigger item in cart = NO [+] discount category item in cart = YES
		} elseif ($this->clause == 1 && $productincart == 0 && $discountcatitems == 1) {
			$GLOBALS['ISC_CLASS_CART']->api->SetArrayPush('DISCOUNT_MESSAGES2', sprintf(GetLang($this->getName().'DiscountMessage4'), $this->triggerproductqty, $triggeritemlink, $this->triggerproduct, $this->amount, $catlink, $triggeritemaddlink, ($this->triggerproductqty - $setquantity), $this->triggerproduct, $discountexcludes));
		
		//Message 5 - Clause = 1 [+] trigger item in cart = YES [+] trigger item has sufficient quantity = NO [+] discount category item in cart = NO [+] forced discount message = YES
		} elseif ($this->clause == 1 && $productincart == 1 && $triggerproductactive == 0 && $discountcatitems == 0 && $this->forcediscountmessage == 1) {
			$GLOBALS['ISC_CLASS_CART']->api->SetArrayPush('DISCOUNT_MESSAGES2', sprintf(GetLang($this->getName().'DiscountMessage5'), ($this->triggerproductqty - $setquantity), $triggeritemlink, $this->triggerproduct, $this->amount, $catlink, $triggeritemaddlink, ($this->triggerproductqty - $setquantity), $this->triggerproduct, $discountexcludes));
			
		//Message 6 - Clause = 1 [+] trigger item in cart = YES [+] trigger item has sufficient quantity = YES [+] discount category item in cart = NO [+] forced discount message = YES
		} elseif ($this->clause == 1 && $productincart == 1 && $triggerproductactive == 1 && $discountcatitems == 0 && $this->forcediscountmessage == 1) {
			$GLOBALS['ISC_CLASS_CART']->api->SetArrayPush('DISCOUNT_MESSAGES2', sprintf(GetLang($this->getName().'DiscountMessage6'), $this->amount, $catlink, $discountexcludes));	
			
		//Message 7 - Clause = 1 [+] trigger item in cart = YES [+] trigger item has sufficient quantity = NO [+] discount category item in cart = YES
		} elseif ($this->clause == 1 && $productincart == 1 && $triggerproductactive == 0 && $discountcatitems == 1) {
			$GLOBALS['ISC_CLASS_CART']->api->SetArrayPush('DISCOUNT_MESSAGES2', sprintf(GetLang($this->getName().'DiscountMessage7'), ($this->triggerproductqty - $setquantity), $triggeritemlink, $this->triggerproduct, $this->amount, $catlink, $triggeritemaddlink, ($this->triggerproductqty - $setquantity), $this->triggerproduct, $discountexcludes, $discountexcludes));
		
		//Message 8 - Clause = 1 [+] trigger item in cart = YES [+] trigger item has sufficient quantity = YES [+] discount category item in cart = YES
		} elseif ($this->clause == 1 && $productincart == 1 && $triggerproductactive == 1 && $discountcatitems == 1) {
			$GLOBALS['ISC_CLASS_CART']->api->SetArrayPush('DISCOUNT_MESSAGES', sprintf(GetLang($this->getName().'DiscountMessage8'), $this->amount, $catlink, $discountexcludes));
		
		
		//Run messages for the order minimum clause
		
		//Message 9 - Clause = 2 [+] sufficient order amount = NO [+] discount category item in cart = NO [+] forced discount message = YES
		} elseif ($this->clause == 2 && $cartTotal < $this->minimumorder && $discountcatitems == 0 && $this->forcediscountmessage == 1) {	
			$GLOBALS['ISC_CLASS_CART']->api->SetArrayPush('DISCOUNT_MESSAGES2', sprintf(GetLang($this->getName().'DiscountMessage9'), $minimumordertext, $this->amount, $catlink, $spendtoqualifytext, $discountexcludes));
		
		//Message 10 - Clause = 2 [+] sufficient order amount = NO [+] discount category item in cart = YES
		} elseif ($this->clause == 2 && $cartTotal < $this->minimumorder && $discountcatitems == 1) {	
			$GLOBALS['ISC_CLASS_CART']->api->SetArrayPush('DISCOUNT_MESSAGES2', sprintf(GetLang($this->getName().'DiscountMessage10'), $minimumordertext, $this->amount, $catlink, $spendtoqualifytext, $discountexcludes));
			
		//Message 11 - Clause = 2 [+] sufficient order amount = YES [+] discount category item in cart = NO [+] forced discount message = YES
		} elseif ($this->clause == 2 && $cartTotal >= $this->minimumorder && $discountcatitems == 0 && $this->forcediscountmessage == 1) {	
			$GLOBALS['ISC_CLASS_CART']->api->SetArrayPush('DISCOUNT_MESSAGES2', sprintf(GetLang($this->getName().'DiscountMessage11'), $this->amount, $catlink, $discountexcludes));
		
		//Message 12 - Clause = 2 [+] sufficient order amount = YES [+] discount category item in cart = YES
		} elseif ($this->clause == 2 && $cartTotal >= $this->minimumorder && $discountcatitems == 1) {	
			$GLOBALS['ISC_CLASS_CART']->api->SetArrayPush('DISCOUNT_MESSAGES', sprintf(GetLang($this->getName().'DiscountMessage12'), $this->amount, $catlink, $discountexcludes));
			
		
		//Run messages for the cart quantity clause
		
		//Message 13 - Clause = 3 [+] sufficient item quantity in cart = NO [+] forced discount message = YES
		} elseif ($this->clause == 3 && $currentcartqty < $this->cartqty && $this->forcediscountmessage == 1) {	
			$GLOBALS['ISC_CLASS_CART']->api->SetArrayPush('DISCOUNT_MESSAGES2', sprintf(GetLang($this->getName().'DiscountMessage13'), $itemstilltrigger, $mess1, $this->amount, $mess2, $discountexcludes));
			
		//Message 14 - Clause = 3 [+] sufficient item quantity in cart = YES
		} elseif ($this->clause == 3 && $currentcartqty >= $this->cartqty) {	
			$GLOBALS['ISC_CLASS_CART']->api->SetArrayPush('DISCOUNT_MESSAGES', sprintf(GetLang($this->getName().'DiscountMessage14'), $this->amount, $mess2, $discountexcludes));


		//Coupon has been applied to cart
		} elseif ($this->clause == 9) {	
			$GLOBALS['ISC_CLASS_CART']->api->SetArrayPush('DISCOUNT_MESSAGES2', sprintf(GetLang($this->getName().'DiscountMessageCoupon')));
			
		}		
		
		
		if (!empty($found)) {
			return true;
		}

		return false;
	}

	public function haltReset()
	{
		return false;
	}

}
